Index: tools/testing/drt-trampoline.py |
diff --git a/tools/testing/drt-trampoline.py b/tools/testing/drt-trampoline.py |
index ac5b23d690af3de4017eebf27fa14da8ecb55ada..fc59861a1169cf87f0b30cff726a711fb7998ec9 100644 |
--- a/tools/testing/drt-trampoline.py |
+++ b/tools/testing/drt-trampoline.py |
@@ -3,7 +3,7 @@ |
# BSD-style license that can be found in the LICENSE file. |
# |
# For now we have to use this trampoline to turn --dart-flags command line |
# switch into env variable DART_FLAGS. Eventually, DumpRenderTree should |
# support --dart-flags and this hack may go away. |
# |
# Expected invocation: python drt-trampoline.py <path to DRT> <DRT command line> |
@@ -132,8 +132,8 @@ def main(argv): |
print 'FAIL' |
print 'Expectation didn\'t match.\n' |
if len(output) == 0: |
- print ('\033[31mERROR\033[0m: DumpRenderTree generated an empty pixel ' |
- 'output! This is commonly an error in executing DumpRenderTree, and' |
+ print ('\033[31mERROR\033[0m: Content shell generated an empty pixel ' |
+ 'output! This is commonly an error in executing content shell, and' |
' not that expectations are out of date.\n') |
print 'You can update expectations by running:\n' |
print 'cp %s %s\n' % (out_file, out_expected_file) |
@@ -3,7 +3,7 @@ |
# |
# For now we have to use this trampoline to turn --dart-flags command line |
-# switch into env variable DART_FLAGS. Eventually, DumpRenderTree should |
+# switch into env variable DART_FLAGS. Eventually, Content shell should |
# support --dart-flags and this hack may go away. |
# |